Functions
===================================

:class:`atmosphyre.AD_simulation` About my class.
:meth:`atmosphyre.AD_simulation.load_wavelengths` And my cool function


.. py:class:: atmosphyre.AD_simulation(**kwargs)

   Class
   
   :param float telescope_diameter: telescope diameter in m

.. py:method:: atmosphyre.AD_simulation.load_wavelengths(wavelengths=[])

function

:param list wavelengths: list of wavelengths in um

:return: the message id
:rtype: int

.. py:method:: atmosphyre.AD_simulation.load_hour_angles(**kwargs)

function

:param str sender: The person sending the message


This is a test

.. autofunction:: atmosphyre.AD_simulation.load_wavelengths

:class:`atmosphyre.AD_simulation` About my class.
:meth:`atmosphyre.AD_simulation.load_wavelengths` And my cool function

.. py:module:: atmosphyre

.. py:currentmodule:: atmosphyre

.. py:class:: AD_simulation
    .. py:method:: load_wavelengths


.. automodule:: atmosphyre.disp1
    :members:
    :private-members:
    :special-members: